/*******************************************************************************
 FileName:      HardwareProfile.h
 Dependencies:  See INCLUDES section
 Processor:     PIC18, PIC24, or PIC32 USB Microcontrollers
 Hardware:      The code is natively intended to be used on the 
                following hardware platforms: 
                    PICDEM FS USB Demo Board
                    Explorer 16 + PIC24 or PIC32 USB PIMs
                The firmware may be modified for use on other USB 
                platforms by editing this file (HardwareProfile.h)
 Compiler:  	Microchip C18 (for PIC18), C30 (for PIC24), or C32 (for PIC32)
 Company:       Microchip Technology, Inc.

 Software License Agreement:

 The software supplied herewith by Microchip Technology Incorporated
 (the Company) for its PIC Microcontroller is intended and
 supplied to you, the Companys customer, for use solely and
 exclusively on Microchip PIC Microcontroller products. The
 software is owned by the Company and/or its supplier, and is
 protected under applicable copyright laws. All rights are reserved.
 Any use in violation of the foregoing restrictions may subject the
 user to criminal sanctions under applicable laws, as well as to
 civil liability for the breach of the terms and conditions of this
 license.

 THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

********************************************************************************
 File Description:

 Change History:
  Rev   Date         Description
  1.0   11/19/2004   Initial release
  2.1   02/26/2007   Updated for simplicity and to use common
                     coding style
  2.3   09/15/2008   Broke out each hardware platform into its own
                     "HardwareProfile - xxx.h" file
  3.0   10/12/2009   COM3101 v1.0
*******************************************************************************/

#ifndef HARDWARE_PROFILE_H
#define HARDWARE_PROFILE_H

//#define DEMO_BOARD USER_DEFINED_BOARD

#if !defined(DEMO_BOARD)
    #if defined(__C32__)
        #if defined(__32MX460F512L__)
            //#define USE_SELF_POWER_SENSE_IO
            #define tris_self_power     TRISAbits.TRISA2    // Input
            #define self_power          1
            //#define USE_USB_BUS_SENSE_IO
            #define tris_usb_bus_sense  TRISBbits.TRISB5    // Input
            #define USB_BUS_SENSE       1 
            /** Board definition ***********************************************/
            //  These defintions will tell the main() function which board is
            //  currently selected.  This will allow the application to add
            //  the correct configuration bits as wells use the correct
            //  initialization functions for the board.  These defitions are only
            //  required in the stack provided demos.  They are not required in
            //  final application design.
            #define DEMO_BOARD PIC32MX460F512L_PIM
            #define EXPLORER_16
            #define PIC32MX460F512L_PIM
            /** LED ************************************************************/
            #define mInitAllLEDs()      LATA &= 0xFFF0; TRISA &= 0xFFF0;
            #define mLED_1              LATAbits.LATA0
            #define mLED_2              LATAbits.LATA1
            #define mLED_3              LATAbits.LATA2
            #define mLED_4              LATAbits.LATA3
            /** SWITCH *********************************************************/
            #define mInitSwitch3()      TRISDbits.TRISD6=1;
            #define mInitSwitch4()      TRISAbits.TRISA7=1;
            #define mInitSwitch5()      TRISDbits.TRISD13=1;
            #define mInitSwitch6()      TRISDbits.TRISD7=1;
            #define mInitAllSwitches()  mInitSwitch3();mInitSwitch4();mInitSwitch5();mInitSwitch6();
            #define sw3                 PORTDbits.RD6
            #define sw4                 PORTAbits.RA7
            #define sw5                 PORTDbits.RD13
            #define sw6                 PORTDbits.RD7
        #endif
    #endif
    
    #if defined(__C30__)
        #if defined(__PIC24FJ256GB110__)
            //#define USE_SELF_POWER_SENSE_IO
            #define tris_self_power     TRISAbits.TRISA2    // Input
            #define self_power          1
            //#define USE_USB_BUS_SENSE_IO
            #define tris_usb_bus_sense  TRISBbits.TRISB5    // Input
            #define USB_BUS_SENSE       U1OTGSTATbits.SESVD 
            /** Board definition ***********************************************/
            //  These defintions will tell the main() function which board is
            //  currently selected.  This will allow the application to add
            //  the correct configuration bits as wells use the correct
            //  initialization functions for the board.  These defitions are only
            //  required in the stack provided demos.  They are not required in
            //  final application design.
            #define DEMO_BOARD PIC24FJ256GB110_PIM
            #define EXPLORER_16
            #define PIC24FJ256GB110_PIM
            #define CLOCK_FREQ 32000000
            /** LED ************************************************************/
            #define mInitAllLEDs()      LATA &= 0xFFF0; TRISA &= 0xFFF0;
            #define mLED_1              LATAbits.LATA0
            #define mLED_2              LATAbits.LATA1
            #define mLED_3              LATAbits.LATA2
            #define mLED_4              LATAbits.LATA3
            /** SWITCH *********************************************************/
            #define mInitSwitch3()      TRISDbits.TRISD6=1;
            #define mInitSwitch4()      TRISAbits.TRISA7=1;
            #define mInitSwitch5()      TRISDbits.TRISD13=1;
            #define mInitSwitch6()      TRISDbits.TRISD7=1;
            #define mInitAllSwitches()  mInitSwitch3();mInitSwitch4();mInitSwitch5();mInitSwitch6();
            #define sw3                 PORTDbits.RD6
            #define sw4                 PORTAbits.RA7
            #define sw5                 PORTDbits.RD13
            #define sw6                 PORTDbits.RD7
        #endif
    #endif

    #if defined(__18CXX)
        #if defined(__18F4550)
            //The PICDEM FS USB Demo Board platform supports the USE_SELF_POWER_SENSE_IO
            //and USE_USB_BUS_SENSE_IO features.  Uncomment the below line(s) if
            //it is desireable to use one or both of the features.
            //#define USE_SELF_POWER_SENSE_IO
            #define tris_self_power     TRISAbits.TRISA2    // Input
            #if defined(USE_SELF_POWER_SENSE_IO)
                #define self_power          PORTAbits.RA2
            #else
                #define self_power          1
            #endif
            //#define USE_USB_BUS_SENSE_IO
            #define tris_usb_bus_sense  TRISAbits.TRISA1    // Input
            #if defined(USE_USB_BUS_SENSE_IO)
                #define USB_BUS_SENSE       PORTAbits.RA1
            #else
                #define USB_BUS_SENSE       1
            #endif
            /** Board definition ***********************************************/
            //  These defintions will tell the main() function which board is
            //  currently selected.  This will allow the application to add
            //  the correct configuration bits as wells use the correct
            //  initialization functions for the board.  These defitions are only
            //  required in the stack provided demos.  They are not required in
            //  final application design.
            #define DEMO_BOARD PICDEM_FS_USB
            #define PICDEM_FS_USB
            #define CLOCK_FREQ 48000000
            /** LED ************************************************************/
            #define mInitAllLEDs()      LATD &= 0xF0; TRISD &= 0xF0;
            #define mLED_1              LATDbits.LATD0
            #define mLED_2              LATDbits.LATD1
            #define mLED_3              LATDbits.LATD2
            #define mLED_4              LATDbits.LATD3
            /** SWITCH *********************************************************/
            #define mInitSwitch2()      TRISBbits.TRISB4=1;
            #define mInitSwitch3()      TRISBbits.TRISB5=1;
            #define mInitAllSwitches()  mInitSwitch2();mInitSwitch3();
            #define sw2                 PORTBbits.RB4
            #define sw3                 PORTBbits.RB5
            /** SPI : Chip Select Lines ****************************************/
            #define tris_cs_temp_sensor TRISBbits.TRISB2    // Output
            #define cs_temp_sensor      LATBbits.LATB2

        #elif defined(__18F14K50)
            //#define USE_SELF_POWER_SENSE_IO	
            #define tris_self_power     TRISAbits.TRISA2    // Input
            #if defined(USE_SELF_POWER_SENSE_IO)
                #define self_power          PORTAbits.RA2
            #else
                #define self_power          1
            #endif
            //#define USE_USB_BUS_SENSE_IO
            #define tris_usb_bus_sense  TRISAbits.TRISA1    // Input
            #if defined(USE_USB_BUS_SENSE_IO)
                #define USB_BUS_SENSE       PORTAbits.RA1
            #else
                #define USB_BUS_SENSE       1
            #endif
            /** Board definition ***********************************************/
            //  These defintions will tell the main() function which board is
            //  currently selected.  This will allow the application to add
            //  the correct configuration bits as wells use the correct
            //  initialization functions for the board.  These defitions are only
            //  required in the stack provided demos.  They are not required in
            //  final application design.
            #define DEMO_BOARD LOW_PIN_COUNT_USB_DEVELOPMENT_KIT
            #define LOW_PIN_COUNT_USB_DEVELOPMENT_KIT
            #define CLOCK_FREQ 48000000
            #define GetSystemClock() CLOCK_FREQ
            /** LED ************************************************************/
            #define mInitAllLEDs()      LATC &= 0xF0; TRISC &= 0xF0;
            #define mLED_1              LATCbits.LATC0
            #define mLED_2              LATCbits.LATC1
            #define mLED_3              LATCbits.LATC2
            #define mLED_4              LATCbits.LATC3
            /** SWITCH *********************************************************/
            #define mInitSwitch1()      // RA3 is always an input pin
            #define sw1                 PORTAbits.RA3
            #define mInitAllSwitches()  mInitSwitch1();

        #endif
    #endif
    
    /** LED MACROS *****************************************************/
    #define mGetLED_1()         mLED_1
    #define mGetLED_2()         mLED_2
    #define mGetLED_3()         mLED_3
    #define mGetLED_4()         mLED_4
    #define mLED_1_On()         mLED_1 = 1;
    #define mLED_2_On()         mLED_2 = 1;
    #define mLED_3_On()         mLED_3 = 1;
    #define mLED_4_On()         mLED_4 = 1;
    #define mLED_1_Off()        mLED_1 = 0;
    #define mLED_2_Off()        mLED_2 = 0;
    #define mLED_3_Off()        mLED_3 = 0;
    #define mLED_4_Off()        mLED_4 = 0;
    #define mLED_1_Toggle()     mLED_1 = !mLED_1;
    #define mLED_2_Toggle()     mLED_2 = !mLED_2;
    #define mLED_3_Toggle()     mLED_3 = !mLED_3;
    #define mLED_4_Toggle()     mLED_4 = !mLED_4;
    
    /** LAB SWITCH *****************************************************/
    #if defined(LOW_PIN_COUNT_USB_DEVELOPMENT_KIT)
        #define sw  sw1
    #elif defined(PICDEM_FS_USB)
        #define sw  sw2
    #elif defined(EXPLORER_16)
        #define sw  sw3
    #endif

    /** I/O pin definitions ********************************************/
    #define INPUT_PIN 1
    #define OUTPUT_PIN 0
#endif

#if !defined(DEMO_BOARD)
    #error "Demo board not defined.  Either define DEMO_BOARD for a custom board or select the correct processor for the demo board."
#endif

#endif  //HARDWARE_PROFILE_H
