#include <p18cxxx.h>
#include "SoftwareSPI.h"

// Copied from Peripheral libraries, changed name with a prepended
// 'L' for Local.  The code here is the same, only difference are the
// pin assignments.  I didn't want to make a global change to the
// PIC18F14K50 peripheral library.
// DZB 05May2008
/********************************************************************
*       Function Name:  ClearCSSWSPI                                *
*       Return Value:   void                                        *
*       Parameters:     void                                        *
*       Description:    This routine sets the CS pin low.           *
********************************************************************/
void LClearCSSWSPI(void)
{
//        SW_CS_PIN = 0;                  // Clear the CS pin
}


/********************************************************************
*       Function Name:  SetCSSWSPI                                  *
*       Return Value:   void                                        *
*       Parameters:     void                                        *
*       Description:    This routine sets the CS pin high.          *
********************************************************************/
void LSetCSSWSPI(void)
{
//        SW_CS_PIN = 1;                  // Set the CS pin high
}

/********************************************************************
*       Function Name:  ClearCESWSPI                                *
*       Return Value:   void                                        *
*       Parameters:     void                                        *
*       Description:    This routine sets the CE pin low.           *
********************************************************************/
void LClearCESWSPI(void)
{

	SW_CE_PIN = 0;
}

/********************************************************************
*       Function Name:  SetCESWSPI                                  *
*       Return Value:   void                                        *
*       Parameters:     void                                        *
*       Description:    This routine sets the CS pin high.          *
********************************************************************/
void LSetCESWSPI(void)
{

	SW_CE_PIN = 1;
}

/********************************************************************
*       Function Name:  OpenSWSPI                                   *
*       Return Value:   void                                        *
*       Parameters:     void                                        *
*       Description:    This routine configures the I/O pins for SPI*
*                       operation.                                  *
********************************************************************/
void LOpenSWSPI (void)
{
        SW_CE_PIN = 0;          // Make the CS pin high
        SW_DIN_PIN = 1;         // Make the DIN pin high

#if defined(MODE0)              // Mode 0
        SW_DOUT_PIN = 0;        // Make the Dout and SCK pin low
        SW_SCK_PIN = 0;
#endif

#if defined(MODE1)              // Mode 1
        SW_DOUT_PIN = 0;        // Make the Dout pin low
        SW_SCK_PIN = 1;         // Make the SCK pin high
#endif

#if defined(MODE2)              // Mode 2
        SW_DOUT_PIN = 0;        // Make the Dout and SCK pins low
        SW_SCK_PIN = 0;
#endif

#if defined(MODE3)              // Mode3
        SW_DOUT_PIN = 0;        // Make the Dout pin low
        SW_SCK_PIN = 1;         // Make the SCK pin high
#endif

        TRIS_SW_CE_PIN = 0;     // Make the CS pin an output
        TRIS_SW_DIN_PIN = 1;    // Make the DIN pin an input
        TRIS_SW_DOUT_PIN = 0;   // Make the DOUT pin an output
        TRIS_SW_SCK_PIN = 0;    // Make the SCK pin an output
}


/********************************************************************
*       Function Name:  WriteSWSPI                                  *
*       Return Value:   char: received data                         *
*       Parameters:     data: data to transmit                      *
*       Description:    This routine sets the CS pin high.          *
********************************************************************/
char LWriteSWSPI( char output)
{
        char BitCount;                  // Bit counter
        static char input;

        BitCount = 8;                   // Do 8-bits
        input = output;

#if defined(MODE0)                      // Mode 0
// SCK idles low
// Data output after falling edge of SCK
// Data sampled before rising edge of SCK
        while(BitCount--)                              // Loop 8 times
        {
            SW_SCK_PIN = 0;         // Clear the SCK pin


            SW_SCK_PIN = 1;         // Set the SCK pin
            SW_DOUT_PIN = 0;        // Set Dout to the next bit according to
            if(input&0x80)          // the MSB of data
                SW_DOUT_PIN = 1;
            SW_SCK_PIN = 0;         // Clear the SCK pin
            input <<= 1;
            if(SW_DIN_PIN)          // to the Din pin
              	input |= 1;
        }
#endif

#if defined(MODE1)                      // Mode1
// SCK idles high
// Data output after rising edge of SCK
// Data sampled before falling edge of SCK
        SW_DOUT_PIN = 0;                // Set the Dout pin according to
        if(input&0x80)                  // the MSB of data
                SW_DOUT_PIN = 1;
        Nop();                          // Adjust for jitter
        Nop();
        do                              // Loop 8 times
        {
                STATUSbits.C = 0;       // Set the carry bit according to
                if(SW_DIN_PIN)          // the Din pin
                        STATUSbits.C = 1;
                SW_SCK_PIN = 0;         // Clear the SCK pin
                Rlcf(input);            // Rotate the carry into the data byte
                Nop();                  // Produces a 50% duty cycle clock
                Nop();
                Nop();
                Nop();
                Nop();
                Nop();
                Nop();
                Nop();
                Nop();
                Nop();
                Nop();
                SW_SCK_PIN = 1;         // Set the SCK pin
                SW_DOUT_PIN = 0;        // Set the Dout pin according to the
                if(input&0x80)          // MSB of data
                        SW_DOUT_PIN = 1;
                BitCount--;             // Count iterations through loop
        } while(BitCount);
#endif

#if defined(MODE2)                      // Mode2
// SCK idles low
// Data output after rising edge of SCK
// Data sampled after falling edge of SCK
        do                              // Loop 8 times
        {
                SW_SCK_PIN = 1;         // Set the SCK pin
                SW_DOUT_PIN = 0;        // Set the Dout pin according to
                if(input&0x80)          // the MSB of data
                        SW_DOUT_PIN = 1;
                STATUSbits.C = 0;       // Set the carry bit according to
                if(SW_DIN_PIN)          // the Din pin
                        STATUSbits.C = 1;
                SW_SCK_PIN = 0;         // Clear the SCK pin
                Rlcf(input);            // Rotate the carry into the data byte
                Nop();                  // Produces a 50% duty cycle clock
                Nop();
                Nop();
                Nop();
                Nop();
                BitCount--;             // Count loop iterations
        } while(BitCount);
#endif

#if defined(MODE3)                      // Mode 3
// SCK idles high
// Data output after falling edge of SCK
// Data sampled before rising edge of SCK
        do                              // Loop 8 times
        {
                SW_SCK_PIN = 0;         // Clear the SCK pin
                SW_DOUT_PIN = 0;        // Set the Dout pin according to
                if(input&0x80)          // the MSB of data
                        SW_DOUT_PIN = 1;
                STATUSbits.C = 0;       // Set the carry bit according to
                if(SW_DIN_PIN)          // the state of the Din pin
                        STATUSbits.C = 1;
                SW_SCK_PIN = 1;         // Set the SCK pin
                Rlcf(input);            // Rotate the carry into the data byte
                Nop();                  // Produces a 50% duty cycle clock
                Nop();
                Nop();
                Nop();
                Nop();
                BitCount--;             // Count loop iterations
        } while(BitCount);
#endif

        return(input);                  // Return the received data
}

